{% extends "discussion/base.html" %}

{% block forum_content %}
    <div class="forum-search">
        <h2>Search</h2>
        {% include 'discussion/_search_form.html' %}
    </div>

    <h2>Discussions</h2>
    <ul class="discussion-list">
        {% for obj in object_list %}
            <li><a href="{% url discussion slug=obj.slug %}">{{ obj }}</a></li>
        {% endfor %}
    </ul>
{% endblock %}