{% for comment in first_comments %}
    {% include 'discussion/_comment_detail.html' %}
{% endfor %}
{% if hidden_count %}
    <div class="comment show-hidden">
        <a href="{% url discussion_post pk=post.pk discussion_slug=post.discussion.slug %}">Show {{ hidden_count }} hidden repl{{ hidden_count|pluralize:"y,ies"}}</a>
    </div>
{% endif %}
{% for comment in last_comments %}
    {% include 'discussion/_comment_detail.html' %}
{% endfor %}