body.discussion #forum-content .discussion-list li {
  margin: 10px 0;
  background: #eeeeee;
  border: 1px solid #dddddd; }
  body.discussion #forum-content .discussion-list li a {
    display: block;
    padding: 10px; }
body.discussion #forum-content .forum-search {
  margin: 10px 0;
  overflow: hidden; }
  body.discussion #forum-content .forum-search p {
    float: left;
    margin-right: 10px; }
body.discussion #forum-content .forum-search-results {
  margin: 10px 0; }
  body.discussion #forum-content .forum-search-results .num-results {
    font-weight: 700; }
  body.discussion #forum-content .forum-search-results .post-body .highlight {
    background-color: #aaaaaa; }
body.discussion #forum-content .comment-form {
  padding-left: 10px; }
body.discussion #forum-content .post-form,
body.discussion #forum-content .comment-form {
  margin: 10px 0;
  position: relative;
  overflow: hidden; }
  body.discussion #forum-content .post-form h3,
  body.discussion #forum-content .comment-form h3 {
    font-weight: 700; }
  body.discussion #forum-content .post-form div.body-field,
  body.discussion #forum-content .post-form div.file-upload-field,
  body.discussion #forum-content .post-form .button,
  body.discussion #forum-content .comment-form div.body-field,
  body.discussion #forum-content .comment-form div.file-upload-field,
  body.discussion #forum-content .comment-form .button {
    position: relative; }
  body.discussion #forum-content .post-form div.body-field,
  body.discussion #forum-content .comment-form div.body-field {
    margin: 10px 0; }
  body.discussion #forum-content .post-form div.file-upload-field,
  body.discussion #forum-content .post-form .button,
  body.discussion #forum-content .comment-form div.file-upload-field,
  body.discussion #forum-content .comment-form .button {
    margin: 0 0 10px; }
  body.discussion #forum-content .post-form div.body-field,
  body.discussion #forum-content .comment-form div.body-field {
    height: auto; }
    body.discussion #forum-content .post-form div.body-field textarea,
    body.discussion #forum-content .comment-form div.body-field textarea {
      left: 10px;
      -moz-box-sizing: border-box;
      -webkit-box-sizing: border-box;
      box-sizing: border-box;
      width: 100%;
      min-width: 100%;
      max-width: 100%;
      height: 10em;
      resize: none;
      display: block;
      padding: 5px;
      overflow: auto;
      border: 1px solid #cccccc; }
      .lt-ie9 body.discussion #forum-content .post-form div.body-field textarea, .lt-ie9
      body.discussion #forum-content .comment-form div.body-field textarea {
        min-width: auto;
        max-width: auto; }
      .lt-ie8 body.discussion #forum-content .post-form div.body-field textarea, .lt-ie8
      body.discussion #forum-content .comment-form div.body-field textarea {
        width: 98%;
        min-width: 98%;
        max-width: 98%; }
      body.discussion #forum-content .post-form div.body-field textarea.autogrow,
      body.discussion #forum-content .comment-form div.body-field textarea.autogrow {
        height: 6em; }
        .lt-ie8 body.discussion #forum-content .post-form div.body-field textarea.autogrow, .lt-ie8
        body.discussion #forum-content .comment-form div.body-field textarea.autogrow {
          height: 4em; }
    body.discussion #forum-content .post-form div.body-field label,
    body.discussion #forum-content .comment-form div.body-field label {
      display: none; }
  body.discussion #forum-content .post-form div.file-upload-field,
  body.discussion #forum-content .comment-form div.file-upload-field {
    float: left;
    margin-top: 0;
    margin-left: 10px; }
  body.discussion #forum-content .post-form .button,
  body.discussion #forum-content .comment-form .button {
    display: block;
    float: right; }
  body.discussion #forum-content .post-form ul.errorlist li,
  body.discussion #forum-content .comment-form ul.errorlist li {
    margin: 10px 0;
    background-color: #c8706f;
    color: white;
    padding: 2px 4px 3px;
    font-weight: bold;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px; }
body.discussion #forum-content .comment, body.discussion #forum-content .post {
  border: 1px solid #dddddd;
  margin: 10px 0;
  padding: 10px;
  overflow: hidden; }
  body.discussion #forum-content .comment .post-info, body.discussion #forum-content .post .post-info {
    overflow: hidden; }
  body.discussion #forum-content .comment .user-name, body.discussion #forum-content .post .user-name {
    font-size: 90%;
    font-weight: 700;
    margin: 0;
    padding: 0; }
  body.discussion #forum-content .comment .post-date,
  body.discussion #forum-content .comment .comment-date, body.discussion #forum-content .post .post-date, body.discussion #forum-content .post .comment-date {
    font-size: 90%;
    color: #999999; }
  body.discussion #forum-content .comment .post-body, body.discussion #forum-content .post .post-body {
    color: #252525;
    background: #eeeeee;
    padding: 10px;
    margin: 10px 0; }
  body.discussion #forum-content .comment .comment-count, body.discussion #forum-content .post .comment-count {
    float: left;
    line-height: 1;
    margin-right: 20px;
    font-size: 90%;
    font-style: italic;
    color: #999999; }
  body.discussion #forum-content .comment .post-links, body.discussion #forum-content .post .post-links {
    float: left;
    line-height: 1;
    margin: 0 0 10px 0; }
    body.discussion #forum-content .comment .post-links .post-reply, body.discussion #forum-content .comment .post-links .post-permalink, body.discussion #forum-content .post .post-links .post-reply, body.discussion #forum-content .post .post-links .post-permalink {
      margin-right: 20px;
      font-size: 90%;
      text-decoration: none; }
  body.discussion #forum-content .comment .post-attachment, body.discussion #forum-content .post .post-attachment {
    clear: both;
    margin: 0 0 10px 70px;
    font-size: 11px;
    font-weight: 700; }
    body.discussion #forum-content .comment .post-attachment a, body.discussion #forum-content .post .post-attachment a {
      text-decoration: none; }
  body.discussion #forum-content .comment h3.replies, body.discussion #forum-content .post h3.replies {
    margin-top: 10px;
    font-weight: 700; }
  body.discussion #forum-content .comment .post-comments, body.discussion #forum-content .post .post-comments {
    clear: both; }
body.discussion #forum-content .posts-wrapper .post {
  margin: 10px 0; }
